Testing Neutron Dynamic Routing
===============================

Please see the TESTING.rst file for the Neutron project itself. This will have
the latest up to date instructions for how to test Neutron, and will
be applicable to neutron-dynamic-routing as well:

`Neutron TESTING.rst <https://git.openstack.org/cgit/openstack/neutron/tree/TESTING.rst>`_
